nltk.tokenize package
=====================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.tokenize.api
   nltk.tokenize.casual
   nltk.tokenize.destructive
   nltk.tokenize.legality_principle
   nltk.tokenize.mwe
   nltk.tokenize.nist
   nltk.tokenize.punkt
   nltk.tokenize.regexp
   nltk.tokenize.repp
   nltk.tokenize.sexpr
   nltk.tokenize.simple
   nltk.tokenize.sonority_sequencing
   nltk.tokenize.stanford
   nltk.tokenize.stanford_segmenter
   nltk.tokenize.texttiling
   nltk.tokenize.toktok
   nltk.tokenize.treebank
   nltk.tokenize.util

Module contents
---------------

.. automodule:: nltk.tokenize
   :members:
   :undoc-members:
   :show-inheritance:
